@@ -18,7 +18,7 @@
 #' @param subset an optional subset containing rows of data to keep. For best
 #' results, pass a logical vector of rows to keep. Also supports
 #' \code{\link[base]{subset}()} functions.
-#' @inheritParams forecast
+#' @inheritParams forecast.ts
 #'
 #' @param ... Other arguments passed to \code{\link[stats]{lm}()}
 #' @return Returns an object of class "lm".
@@ -146,8 +146,9 @@ tslm <- function(formula, data, subset, lambda=NULL, biasadj=FALSE, ...) {
     data <- data[subset, ] # model.frame(formula,as.data.frame(data[subsetTF,]))
   }
   if (!is.null(lambda)) {
-    data[, 1] <- BoxCox(data[, 1], lambda)
-    lambda <- attr(data[, 1], "lambda")
+    resp_var <- deparse(attr(mt, "variables")[[attr(mt, "response") + 1]])
+    data[, resp_var] <- BoxCox(data[, resp_var], lambda)
+    lambda <- attr(data[, resp_var], "lambda")
   }
   if (tsdat[2] == 0 && tsvar[2] != 0) {
     data$season <- factor(data$season) # fix for lost factor information, may not be needed?
@@ -209,7 +210,7 @@ fitted.tslm <- function(object, ...){
 #' interpreted as related to the subsequent time periods. If \code{FALSE}, any
 #' time series attributes of the original data will be ignored.
 #' @param ... Other arguments passed to \code{\link[stats]{predict.lm}()}.
-#' @inheritParams forecast
+#' @inheritParams forecast.ts
 #'
 #' @return An object of class "\code{forecast}".
 #'
@@ -470,7 +471,7 @@ forecast.lm <- function(object, newdata, h=10, level=c(80, 95), fan=FALSE, lambd
   }
 
   if (!is.null(lambda)) {
-    fcast$x <- InvBoxCox(fcast$x, lambda)
+    #fcast$x <- InvBoxCox(fcast$x, lambda)
     fcast$mean <- InvBoxCox(fcast$mean, lambda, biasadj, fcast)
     fcast$lower <- InvBoxCox(fcast$lower, lambda)
     fcast$upper <- InvBoxCox(fcast$upper, lambda)
