@@ -56,7 +56,7 @@
 #' @param x Deprecated. Included for backwards compatibility.
 #' @param \dots Other arguments passed to \code{\link[nnet]{nnet}} for
 #' \code{nnetar}.
-#' @inheritParams forecast
+#' @inheritParams forecast.ts
 #'
 #' @return Returns an object of class "\code{nnetar}".
 #'
@@ -322,7 +322,7 @@ nnetar <- function(y, p, P=1, size, repeats=20, xreg=NULL, lambda=NULL, model=NU
   }
   out$fitted <- ts(rep(NA_real_, length(out$x)))
   out$fitted[c(rep(TRUE, maxlag), j)] <- fits
-  tsp(out$fitted) <- tsp(out$x)
+  out$fitted <- copy_msts(out$x, out$fitted)
   out$residuals <- out$x - out$fitted
   out$lags <- lags
   out$series <- yname
@@ -404,7 +404,7 @@ print.nnetarmodels <- function(x, ...) {
 #' a matrix with \code{h} rows and \code{npaths} columns (vectors are coerced
 #' into a matrix). If present, \code{bootstrap} is ignored.
 #' @param ... Additional arguments passed to \code{\link{simulate.nnetar}}
-#' @inheritParams forecast
+#' @inheritParams forecast.ts
 #'
 #' @return An object of class "\code{forecast}".
 #'
@@ -541,8 +541,8 @@ forecast.nnetar <- function(object, h=ifelse(object$m > 1, 2 * object$m, 10), PI
     }
     for (i in 1:npaths)
       sim[i, ] <- simulate(object, nsim = h, bootstrap = bootstrap, xreg = xreg, lambda = lambda, innov = innov[, i], ...)
-    lower <- apply(sim, 2, quantile, 0.5 - level / 200, type = 8)
-    upper <- apply(sim, 2, quantile, 0.5 + level / 200, type = 8)
+    lower <- apply(sim, 2, quantile, 0.5 - level / 200, type = 8, na.rm = TRUE)
+    upper <- apply(sim, 2, quantile, 0.5 + level / 200, type = 8, na.rm = TRUE)
     if (nint > 1L) {
       lower <- ts(t(lower))
       upper <- ts(t(upper))
@@ -551,17 +551,17 @@ forecast.nnetar <- function(object, h=ifelse(object$m > 1, 2 * object$m, 10), PI
       lower <- ts(matrix(lower, ncol = 1L))
       upper <- ts(matrix(upper, ncol = 1L))
     }
-    tsp(lower) <- tsp(upper) <- tsp(fcast)
+    out$lower <- future_msts(out$x, lower)
+    out$upper <- future_msts(out$x, upper)
   }
   else {
     level <- NULL
     lower <- NULL
     upper <- NULL
   }
-  out$mean <- fcast
+  out$mean <- future_msts(out$x, fcast)
   out$level <- level
-  out$lower <- lower
-  out$upper <- upper
+
   return(structure(out, class = "forecast"))
 }
 
